<?php

/**
 * @license LGPLv3, http://opensource.org/licenses/LGPL-3.0
 * @copyright Aimeos (aimeos.org), 2015-2024
 * @package MShop
 * @subpackage Customer
 */


namespace Aimeos\MShop\Customer\Manager\Lists\Type;


/**
 * Laravel implementation of the customer list type class.
 *
 * @package MShop
 * @subpackage Customer
 */
class Laravel
	extends \Aimeos\MShop\Customer\Manager\Lists\Type\Standard
{
	private array $searchConfig = array(
		'customer.lists.type.id' => array(
			'code' =>'customer.lists.type.id',
			'internalcode' =>'mcuslity."id"',
			'label' =>'Customer list type ID',
			'type' => 'int',
			'public' => false,
		),
		'customer.lists.type.siteid' => array(
			'code' =>'customer.lists.type.siteid',
			'internalcode' =>'mcuslity."siteid"',
			'label' =>'Customer list type site ID',
			'type' => 'string',
			'public' => false,
		),
		'customer.lists.type.code' => array(
			'code' =>'customer.lists.type.code',
			'internalcode' =>'mcuslity."code"',
			'label' =>'Customer list type code',
			'type' => 'string',
		),
		'customer.lists.type.domain' => array(
			'code' =>'customer.lists.type.domain',
			'internalcode' =>'mcuslity."domain"',
			'label' =>'Customer list type domain',
			'type' => 'string',
		),
		'customer.lists.type.label' => array(
			'code' =>'customer.lists.type.label',
			'internalcode' =>'mcuslity."label"',
			'label' =>'Customer list type label',
			'type' => 'string',
		),
		'customer.lists.type.status' => array(
			'code' =>'customer.lists.type.status',
			'internalcode' =>'mcuslity."status"',
			'label' =>'Customer list type status',
			'type' => 'int',
		),
		'customer.lists.type.position' => array(
			'code' =>'customer.lists.type.position',
			'internalcode' =>'mcuslity."pos"',
			'label' =>'Customer list type position',
			'type' => 'int',
		),
		'customer.lists.type.ctime' => array(
			'code' =>'customer.lists.type.ctime',
			'internalcode' =>'mcuslity."ctime"',
			'label' =>'Customer list type create date/time',
			'type' => 'datetime',
		),
		'customer.lists.type.mtime' => array(
			'code' =>'customer.lists.type.mtime',
			'internalcode' =>'mcuslity."mtime"',
			'label' =>'Customer list type modification date/time',
			'type' => 'datetime',
		),
		'customer.lists.type.editor' => array(
			'code' =>'customer.lists.type.editor',
			'internalcode' =>'mcuslity."editor"',
			'label' =>'Customer list type editor',
			'type' => 'string',
		),
		'customer.lists.type.i18n' => array(
			'internalcode' => 'mcuslity."i18n"',
			'label' => 'Type translation',
			'public' => false,
		),
	);


	/**
	 * Removes old entries from the storage.
	 *
	 * @param iterable $siteids List of IDs for sites whose entries should be deleted
	 * @return \Aimeos\MShop\Common\Manager\Iface Same object for fluent interface
	 */
	public function clear( iterable $siteids ) : \Aimeos\MShop\Common\Manager\Iface
	{
		$path = 'mshop/customer/manager/lists/type/submanagers';
		foreach( $this->context()->config()->get( $path, [] ) as $domain ) {
			$this->object()->getSubManager( $domain )->clear( $siteids );
		}

		return $this->clearBase( $siteids, 'mshop/customer/manager/lists/type/laravel/delete' );
	}


	/**
	 * Returns the list attributes that can be used for searching.
	 *
	 * @param bool $withsub Return also attributes of sub-managers if true
	 * @return array List of attribute items implementing \Aimeos\Base\Criteria\Attribute\Iface
	 */
	public function getSearchAttributes( bool $withsub = true ) : array
	{
		$path = 'mshop/customer/manager/lists/type/submanagers';

		return $this->getSearchAttributesBase( $this->searchConfig, $path, [], $withsub );
	}


	/**
	 * Returns a new manager for customer extensions
	 *
	 * @param string $manager Name of the sub manager type in lower case
	 * @param string|null $name Name of the implementation, will be from configuration (or Default) if null
	 * @return \Aimeos\MShop\Common\Manager\Iface Manager for different extensions, e.g stock, tags, locations, etc.
	 */
	public function getSubManager( string $manager, string $name = null ) : \Aimeos\MShop\Common\Manager\Iface
	{
		return $this->getSubManagerBase( 'customer', 'lists/type/' . $manager, ( $name === null ? 'Laravel' : $name ) );
	}


	/**
	 * Returns the config path for retrieving the configuration values.
	 *
	 * @return string Configuration path (mshop/customer/manager/lists/type/laravel/)
	 */
	protected function getConfigPath() : string
	{
		return 'mshop/customer/manager/lists/type/laravel/';
	}


	/**
	 * Returns the search configuration for searching items.
	 *
	 * @return array Associative list of search keys and search definitions
	 */
	protected function getSearchConfig() : array
	{
		return $this->searchConfig;
	}
}
